{ pkgs, lib, ... }:

{

  imports = [
    ./lxterminal
    ./pulsar
    ./zed
    ./mime.nix
    ./mpv.nix
    ./salert.nix
    ./sshuttle.nix
  ];

  # TODO: doesn't work?
  nixpkgs.config.permittedUnfreePackages = [
    pkgs.discord.name
    pkgs.telegram-desktop.name
    pkgs.spotify.name
  ];

  nixpkgs.config.permittedInsecurePackages = [
    pkgs.pulsar.name
    pkgs.zotero.name
  ];

  home.packages = with pkgs; [
    wl-clipboard-timeout

    discord
    element-desktop
    signal-desktop
    #element-desktop-wayland
    #nheko
    #fluffychat

    (pkgs.onlyoffice-desktopeditors or pkgs.unstable.onlyoffice-desktopeditors or pkgs.libreoffice)

    emote
    normcap # doesn't work on wayland
    gcolor3
    icon-library

    gitg

    remote-exec

    (pkgs.zxtune or unstable.zxtune or null)

    f3d
    firefox
    zotero
    (pkgs.loupe or pkgs.gnome.eog)
    evince
    /* papers */

    gnome-connections
    scrcpy
    #spotify # use flathub version instead
    transgui #transmission-remote-gtk
  ]
  ++ builtins.filter (drv: (builtins.tryEval drv.outPath).success) [
    slack
    telegram-desktop
    teams
    zoom-us
  ];

  programs.firefox.enableGnomeExtensions = true;

  home.shellAliases.eog = lib.mkIf (pkgs?loupe) "loupe";

  # flatpak
  # TODO: this requires a logout+login to take effect
  home.activation.addFlathubRemote = lib.hm.dag.entryAfter ["writeBoundary"] ''
    if command -v flatpak >/dev/null; then
      $DRY_RUN_CMD flatpak remote-add --if-not-exists --user flathub https://dl.flathub.org/repo/flathub.flatpakrepo
    fi
  '';
  # TODO: automatic flatpak updates

  # TODO: fix collision
  ## Do not keep me from using the app just to force an update
  #xdg.configFile."discord/settings.json".text = builtins.toJSON {
  #  SKIP_HOST_UPDATE = true;
  #};

}
